pub struct InvalidatedEventBody {
pub areas: Option<Vec<InvalidatedAreas>>,
pub thread_id: Option<i64>,
pub stack_frame_id: Option<i64>,
}Expand description
Arguments for a Invalidated event
Fields
areas: Option<Vec<InvalidatedAreas>>Set of logical areas that got invalidated. This property has a hint
characteristic: a client can only be expected to make a ‘best effort’ in
honouring the areas but there are no guarantees. If this property is
missing, empty, or if values are not understood, the client should assume
a single value all.
thread_id: Option<i64>If specified, the client only needs to refetch data related to this thread.
stack_frame_id: Option<i64>If specified, the client only needs to refetch data related to this stack
frame (and the threadId is ignored).