pub struct MemoryEventBody {
pub memory_reference: String,
pub offset: i64,
pub count: i64,
}Expand description
Arguments for a Memory event.
Fields
memory_reference: StringMemory reference of a memory range that has been updated.
offset: i64Starting offset in bytes where memory has been updated. Can be negative.
count: i64Number of bytes updated.