pub struct OutputEventBody {
pub category: Option<OutputEventCategory>,
pub output: String,
pub group: Option<OutputEventGroup>,
pub variables_reference: Option<i64>,
pub source: Option<Source>,
pub line: Option<i64>,
pub column: Option<i64>,
pub data: Option<Value>,
}Expand description
Arguments for an Output event.
Fields
category: Option<OutputEventCategory>The output category. If not specified or if the category is not
understood by the client, console is assumed.
Values:
‘console’: Show the output in the client’s default message UI, e.g. a
‘debug console’. This category should only be used for informational
output from the debugger (as opposed to the debuggee).
‘important’: A hint for the client to show the output in the client’s UI
for important and highly visible information, e.g. as a popup
notification. This category should only be used for important messages
from the debugger (as opposed to the debuggee). Since this category value
is a hint, clients might ignore the hint and assume the console
category.
‘stdout’: Show the output as normal program output from the debuggee.
‘stderr’: Show the output as error program output from the debuggee.
‘telemetry’: Send the output to telemetry instead of showing it to the
user.
etc.
output: StringThe output to report.
group: Option<OutputEventGroup>Support for keeping an output log organized by grouping related messages.
Values:
‘start’: Start a new group in expanded mode. Subsequent output events are
members of the group and should be shown indented.
The output attribute becomes the name of the group and is not indented.
‘startCollapsed’: Start a new group in collapsed mode. Subsequent output
events are members of the group and should be shown indented (as soon as
the group is expanded).
The output attribute becomes the name of the group and is not indented.
‘end’: End the current group and decrease the indentation of subsequent
output events.
A non-empty output attribute is shown as the unindented end of the
group.
variables_reference: Option<i64>If an attribute variablesReference exists and its value is > 0, the
output contains objects which can be retrieved by passing
variablesReference to the variables request. The value should be less
than or equal to 2147483647 (2^31-1).
source: Option<Source>The source location where the output was produced.
line: Option<i64>The source location’s line where the output was produced.
column: Option<i64>The position in line where the output was produced. It is measured in
UTF-16 code units and the client capability columnsStartAt1 determines
whether it is 0- or 1-based.
data: Option<Value>Additional data to report. For the telemetry category the data is sent
to telemetry, for the other categories the data is shown in JSON format.