pub struct StoppedEventBody {
pub reason: StoppedEventReason,
pub description: Option<String>,
pub thread_id: Option<i64>,
pub preserve_focus_hint: Option<bool>,
pub text: Option<String>,
pub all_threads_stopped: Option<bool>,
pub hit_breakpoint_ids: Option<Vec<i64>>,
}Expand description
Arguments for a Stopped event.
Fields
reason: StoppedEventReasonThe reason for the event.
For backward compatibility this String is shown in the UI if the
description attribute is missing (but it must not be translated).
Values: ‘step’, ‘breakpoint’, ‘exception’, ‘pause’, ‘entry’, ‘goto’,
‘function breakpoint’, ‘data breakpoint’, ‘instruction breakpoint’, etc.
description: Option<String>The full reason for the event, e.g. ‘Paused on exception’. This String is shown in the UI as is and can be translated.
thread_id: Option<i64>The thread which was stopped.
preserve_focus_hint: Option<bool>A value of true hints to the client that this event should not change the focus.
text: Option<String>Additional information. E.g. if reason is exception, text contains the
exception name. This String is shown in the UI.
all_threads_stopped: Option<bool>If allThreadsStopped is true, a debug adapter can announce that all
threads have stopped.
- The client should use this information to enable that all threads can be expanded to access their stacktraces.
- If the attribute is missing or false, only the thread with the given
threadIdcan be expanded.
hit_breakpoint_ids: Option<Vec<i64>>Ids of the breakpoints that triggered the event. In most cases there is only a single breakpoint but here are some examples for multiple breakpoints:
- Different types of breakpoints map to the same location.
- Multiple source breakpoints get collapsed to the same instruction by the compiler/runtime.
- Multiple function breakpoints with different function names map to the same location.