pub struct TerminatedEventBody {
pub restart: Option<Value>,
}Expand description
Arguments for a Terminated event.
Fields
restart: Option<Value>A debug adapter may set restart to true (or to an arbitrary object) to
request that the client restarts the session.
The value is not interpreted by the client and passed unmodified as an
attribute __restart to the launch and attach requests.