pub struct AttachOrLaunchArguments {
pub no_debug: Option<bool>,
pub restart_data: Option<Value>,
pub additional_data: Option<Value>,
}Expand description
Union of Attach and Launch arguments for the Restart request. Currently the same as LaunchRequestArguments but might not be in the future.
Fields
no_debug: Option<bool>If true, the launch request should launch the program without enabling debugging.
restart_data: Option<Value>Arbitrary data from the previous, restarted session.
The data is sent as the restart attribute of the terminated event.
The client should leave the data intact.
additional_data: Option<Value>The request may include additional implementation specific attributes.