pub struct DataBreakpointInfoArguments {
pub variables_reference: Option<i64>,
pub name: String,
pub frame_id: Option<i64>,
}Expand description
Arguments for a DataBreakpointInfo request.
Fields
variables_reference: Option<i64>Reference to the variable container if the data breakpoint is requested for
a child of the container. The variablesReference must have been obtained
in the current suspended state.
See Lifetime of Object References
in the Overview section of the specification for details.
name: StringThe name of the variable’s child to obtain data breakpoint information for.
If variablesReference isn’t specified, this can be an expression.
frame_id: Option<i64>When name is an expression, evaluate it in the scope of this stack frame.
If not specified, the expression is evaluated in the global scope. When
variablesReference is specified, this property has no effect.