pub struct EvaluateArguments {
pub expression: String,
pub frame_id: Option<i64>,
pub context: Option<EvaluateArgumentsContext>,
pub format: Option<ValueFormat>,
}Expand description
Arguments for a Evaluate request.
Fields
expression: StringThe expression to evaluate.
frame_id: Option<i64>Evaluate the expression in the scope of this stack frame. If not specified, the expression is evaluated in the global scope.
context: Option<EvaluateArgumentsContext>The context in which the evaluate request is used.
Values:
‘variables’: evaluate is called from a variables view context.
‘watch’: evaluate is called from a watch view context.
‘repl’: evaluate is called from a REPL context.
‘hover’: evaluate is called to generate the debug hover contents.
This value should only be used if the corresponding capability
supportsEvaluateForHovers is true.
‘clipboard’: evaluate is called to generate clipboard contents.
This value should only be used if the corresponding capability
supportsClipboardContext is true.
etc.
format: Option<ValueFormat>Specifies details on how to format the result.
The attribute is only honored by a debug adapter if the corresponding
capability supportsValueFormattingOptions is true.