pub struct LaunchRequestArguments {
pub no_debug: Option<bool>,
pub restart_data: Option<Value>,
pub additional_data: Option<Value>,
}Expand description
Arguments for a Launch request.
Fields
no_debug: Option<bool>If true, the launch request should launch the program without enabling debugging.
restart_data: Option<Value>Arbitrary data from the previous, restarted session.
The data is sent as the restart attribute of the terminated event.
The client should leave the data intact.
Rust-specific: this data must be a string. Server requiring storing binary data should use an encoding that is suitable for string (e.g. base85 or similar).
additional_data: Option<Value>The request may include additional implementation specific attributes.