pub struct StepBackArguments {
pub thread_id: i64,
pub single_thread: Option<bool>,
pub granularity: Option<SteppingGranularity>,
}Expand description
Arguments for a StepBack request.
Fields
thread_id: i64Specifies the thread for which to resume execution for one step backwards (of the given granularity).
single_thread: Option<bool>If this flag is true, all other suspended threads are not resumed.
granularity: Option<SteppingGranularity>Stepping granularity to step. If no granularity is specified, a granularity
of statement is assumed.