pub struct StepOutArguments {
pub thread_id: i64,
pub single_thread: Option<bool>,
pub granularity: Option<SteppingGranularity>,
}Expand description
Arguments for a StepOut request.
Fields
thread_id: i64Specifies the thread for which to resume execution for one step-out (of the given granularity).
single_thread: Option<bool>If this flag is true, all other suspended threads are not resumed.
granularity: Option<SteppingGranularity>Stepping granularity. If no granularity is specified, a granularity of
statement is assumed.