pub struct VariablesArguments {
pub variables_reference: i64,
pub filter: Option<VariablesArgumentsFilter>,
pub start: Option<i64>,
pub count: Option<i64>,
pub format: Option<ValueFormat>,
}Expand description
Arguments for a Variables request.
Fields
variables_reference: i64The variable for which to retrieve its children. The variablesReference
must have been obtained in the current suspended state.
See Lifetime of Object References
in the Overview section of the specification for details.
filter: Option<VariablesArgumentsFilter>Filter to limit the child variables to either named or indexed. If omitted, both types are fetched. Values: ‘indexed’, ‘named’
start: Option<i64>The index of the first variable to return, if omitted children start at 0.
count: Option<i64>The i64 of variables to return. If count is missing or 0, all variables are returned.
format: Option<ValueFormat>Specifies details on how to format the Variable values.
The attribute is only honored by a debug adapter if the corresponding
capability supportsValueFormattingOptions is true.