pub struct DataBreakpointInfoResponse {
pub data_id: Option<String>,
pub description: String,
pub access_types: Option<Vec<DataBreakpointAccessType>>,
pub can_persist: Option<bool>,
}Fields
data_id: Option<String>An identifier for the data on which a data breakpoint can be registered
with the setDataBreakpoints request or null if no data breakpoint is
available. If a variablesReference or frameId is passed, the dataId
is valid in the current suspended state, otherwise it’s valid
indefinitely. See ‘Lifetime of Object References’ in the Overview section
for details. Breakpoints set using the dataId in the
setDataBreakpoints request may outlive the lifetime of the associated
dataId.
description: StringUI String that describes on what data the breakpoint is set on or why a data breakpoint is not available.
access_types: Option<Vec<DataBreakpointAccessType>>Attribute lists the available access types for a potential data breakpoint. A UI client could surface this information.
can_persist: Option<bool>Attribute indicates that a potential data breakpoint could be persisted across sessions.