pub struct EvaluateResponse {
pub result: String,
pub type_field: Option<String>,
pub presentation_hint: Option<VariablePresentationHint>,
pub variables_reference: i64,
pub named_variables: Option<i64>,
pub indexed_variables: Option<i64>,
pub memory_reference: Option<String>,
}Fields
result: StringThe result of the evaluate request.
type_field: Option<String>The type of the evaluate result.
This attribute should only be returned by a debug adapter if the
corresponding capability supportsVariableType is true.
presentation_hint: Option<VariablePresentationHint>Properties of an evaluate result that can be used to determine how to render the result in the UI.
variables_reference: i64If variablesReference is > 0, the evaluate result is structured and its
children can be retrieved by passing variablesReference to the
variables request.
The value should be less than or equal to 2147483647 (2^31-1).
See Lifetime of Object References
in the Overview section of the specification for details.
named_variables: Option<i64>The i64 of named child variables. The client can use this information to present the variables in a paged UI and fetch them in chunks. The value should be less than or equal to 2147483647 (2^31-1).
indexed_variables: Option<i64>The i64 of indexed child variables. The client can use this information to present the variables in a paged UI and fetch them in chunks. The value should be less than or equal to 2147483647 (2^31-1).
memory_reference: Option<String>A memory reference to a location appropriate for this result.
For pointer type eval results, this is generally a reference to the
memory address contained in the pointer.
This attribute should be returned by a debug adapter if corresponding
capability supportsMemoryReferences is true.