pub struct ReadMemoryResponse {
pub address: String,
pub unreadable_bytes: Option<i64>,
pub data: Option<String>,
}Fields
address: StringThe address of the first byte of data returned.
Treated as a hex value if prefixed with 0x, or as a decimal value
otherwise.
unreadable_bytes: Option<i64>The i64 of unreadable bytes encountered after the last successfully
read byte.
This can be used to determine the i64 of bytes that should be skipped
before a subsequent readMemory request succeeds.
data: Option<String>The bytes read from memory, encoded using base64.