pub struct SetExpressionResponse {
pub value: String,
pub type_field: Option<String>,
pub presentation_hint: Option<VariablePresentationHint>,
pub variables_reference: Option<i64>,
pub named_variables: Option<i32>,
pub indexed_variables: Option<i32>,
}Fields
value: StringThe new value of the expression.
type_field: Option<String>The type of the value.
This attribute should only be returned by a debug adapter if the
corresponding capability supportsVariableType is true.
presentation_hint: Option<VariablePresentationHint>Properties of a value that can be used to determine how to render the result in the UI.
variables_reference: Option<i64>If variablesReference is > 0, the value is structured and its children
can be retrieved by passing variablesReference to the variables
request.
The value should be less than or equal to 2147483647 (2^31-1).
See Lifetime of Object References
in the Overview section of the specification for details.
named_variables: Option<i32>The number of named child variables. The client can use this information to present the variables in a paged UI and fetch them in chunks. The value should be less than or equal to 2147483647 (2^31-1).
indexed_variables: Option<i32>The number of indexed child variables. The client can use this information to present the variables in a paged UI and fetch them in chunks. The value should be less than or equal to 2147483647 (2^31-1).