pub struct SetVariableResponse {
pub value: String,
pub type_field: Option<String>,
pub variables_reference: Option<i64>,
pub named_variables: Option<i32>,
pub indexed_variables: Option<i32>,
}Fields
value: StringThe new value of the variable.
type_field: Option<String>The type of the new value. Typically shown in the UI when hovering over the value.
variables_reference: Option<i64>If variablesReference is > 0, the new value is structured and its
children can be retrieved by passing variablesReference to the
variables request.
The value should be less than or equal to 2147483647 (2^31-1).
See Lifetime of Object References
in the Overview section of the specification for details.
named_variables: Option<i32>The number of named child variables. The client can use this information to present the variables in a paged UI and fetch them in chunks. The value should be less than or equal to 2147483647 (2^31-1).
indexed_variables: Option<i32>The number of indexed child variables. The client can use this information to present the variables in a paged UI and fetch them in chunks. The value should be less than or equal to 2147483647 (2^31-1).