pub struct StackTraceResponse {
pub stack_frames: Vec<StackFrame>,
pub total_frames: Option<i64>,
}Fields
stack_frames: Vec<StackFrame>The frames of the stackframe. If the array has length zero, there are no stackframes available. This means that there is no location information available.
total_frames: Option<i64>The total i64 of frames available in the stack. If omitted or if
totalFrames is larger than the available frames, a client is expected
to request frames until a request returns less frames than requested
(which indicates the end of the stack). Returning monotonically
increasing totalFrames values for subsequent requests can be used to
enforce paging in the client.