ReverseRequest

Struct ReverseRequest 

pub struct ReverseRequest {
    pub seq: i64,
    pub command: ReverseCommand,
}
A debug adapter initiated request.

The specification treats reverse requests identically to all other requests (even though there is a separate section for them). However, in Rust, it is beneficial to separate them because then we don’t need to generate a huge amount of serialization code for all requests and supporting types (that the vast majority of would never be serialized by the adapter, only deserialized).

Fields

seq: i64

Sequence number for the Request.

From the specification:

Sequence number of the message (also known as message ID). The seq for the first message sent by a client or debug adapter is 1, and for each subsequent message is 1 greater than the previous message sent by that actor. seq can be used to order requests, responses, and events, and to associate requests with their corresponding responses. For protocol messages of type request the sequence number can be used to cancel the request.

command: ReverseCommand

The command to execute.

This is stringly typed in the specification, but represented as an enum for better ergonomics in Rust code, along with the arguments when present.