pub struct RunInTerminalRequestArguments {
pub kind: Option<RunInTerminalRequestArgumentsKind>,
pub title: Option<String>,
pub cwd: String,
pub args: Vec<String>,
pub env: Option<HashMap<String, Option<String>>>,
pub args_can_be_interpreted_by_shell: Option<bool>,
}Fields
kind: Option<RunInTerminalRequestArgumentsKind>What kind of terminal to launch. Values: ‘integrated’, ‘external’
title: Option<String>Title of the terminal.
cwd: StringWorking directory for the command. For non-empty, valid paths this typically results in execution of a change directory command.
args: Vec<String>List of arguments. The first argument is the command to run.
env: Option<HashMap<String, Option<String>>>Environment key-value pairs that are added to or removed from the default environment.
args_can_be_interpreted_by_shell: Option<bool>This property should only be set if the corresponding capability
supportsArgsCanBeInterpretedByShell is true. If the client uses an
intermediary shell to launch the application, then the client must not
attempt to escape characters with special meanings for the shell. The user
is fully responsible for escaping as needed and that arguments using
special characters may not be portable across shells.