Module types

Module types 

Structs

Breakpoint
Information about a breakpoint created in setBreakpoints, setFunctionBreakpoints, setInstructionBreakpoints, or setDataBreakpoints requests.
BreakpointLocation
Properties of a breakpoint location returned from the breakpointLocations request. Specfication: BreakpointLocation
Capabilities
Checksum
ColumnDescriptor
CompletionItem
CompletionItems are the suggestions returned from the completions request.
CustomValue
DataBreakpoint
DisassembledInstruction
Represents a single disassembled instruction.
ExceptionBreakpointsFilter
ExceptionDetails
Detailed information about an exception that has occurred.
ExceptionFilterOptions
An ExceptionFilterOptions is used to specify an exception filter together with a condition for the setExceptionBreakpoints request.
ExceptionOptions
An ExceptionOptions assigns configuration options to a set of exceptions.
ExceptionPathSegment
An ExceptionPathSegment represents a segment in a path that is used to match leafs or nodes in a tree of exceptions. If a segment consists of more than one name, it matches the names provided if negate is false or missing, or it matches anything except the names provided if negate is true.
FunctionBreakpoint
Properties of a breakpoint passed to the setFunctionBreakpoints request.
GotoTarget
A GotoTarget describes a code location that can be used as a target in the goto request. The possible goto targets can be determined via the gotoTargets request.
InstructionBreakpoint
Properties of a breakpoint passed to the setInstructionBreakpoints request
Message
A structured message object. Used to return errors from requests.
Module
Scope
A Scope is a named container for variables. Optionally a scope can map to a source or a range within a source.
A Source is a descriptor for source code.
SourceBreakpoint
StackFrame
A Stackframe contains the source location.
StackFrameFormat
Thread
A thread.
ValueFormat
Variable
A Variable is a name/value pair.
VariablePresentationHint

Enums

BreakpointEventReason
ChecksumAlgorithm
ColumnDescriptorType
CompletionItemType
Some predefined types for the CompletionItem. Please note that not all clients have specific icons for all of them
DataBreakpointAccessType
EvaluateArgumentsContext
ExceptionBreakMode
This enumeration defines all possible conditions when a thrown exception should result in a break.
InvalidatedAreas
LoadedSourceEventReason
ModuleEventReason
ModuleId
OutputEventCategory
OutputEventGroup
PresentationHint
ProcessEventStartMethod
RunInTerminalRequestArgumentsKind
ScopePresentationhint
A hint for how to present this scope in the UI. If this attribute is missing, the scope is shown with a generic UI.
StackFrameModuleid
StackFramePresentationhint
StartDebuggingRequestKind
SteppingGranularity
StoppedEventReason
ThreadEventReason
VariablePresentationHintAttributes
Set of attributes represented as an array of Strings. Before introducing additional values, try to use the listed values.
VariablePresentationHintKind
VariablePresentationHintVisibility
VariablesArgumentsFilter