pub enum ExceptionBreakMode {
Never,
Always,
Unhandled,
UserUnhandled,
}Expand description
This enumeration defines all possible conditions when a thrown exception should result in a break.
Specification: ExceptionBreakMode
Variants
Never
never breaks
Always
always breaks
Unhandled
breaks when exception unhandled
UserUnhandled
breaks if the exception is not handled by user code