pub enum ScopePresentationhint {
Arguments,
Locals,
Registers,
String(String),
}Expand description
A hint for how to present this scope in the UI. If this attribute is missing, the scope is shown with a generic UI.
Specification: Scope
Variants
Arguments
Scope contains method arguments.
Locals
Scope contains local variables.
Registers
Scope contains registers. Only a single registers scope
should be returned from a scopes request.
String(String)