pub enum VariablePresentationHintAttributes {
Static,
Constant,
ReadOnly,
RawString,
HasObjectId,
CanHaveObjectId,
HasSideEffects,
HasDataBreakpoint,
String(String),
}Expand description
Set of attributes represented as an array of Strings. Before introducing additional values, try to use the listed values.
Variants
Static
Indicates that the object is static.
Constant
Indicates that the object is a constant.
ReadOnly
Indicates that the object is read only.
RawString
Indicates that the object is a raw String.
HasObjectId
Indicates that the object can have an Object ID created for it.
CanHaveObjectId
Indicates that the object has an Object ID associated with it.
HasSideEffects
Indicates that the evaluation had side effects.
HasDataBreakpoint
Indicates that the object has its value tracked by a data breakpoint.
String(String)