pub enum VariablePresentationHintKind {
Property,
Method,
Class,
Data,
Event,
BaseClass,
InnerClass,
Interface,
MostDerivedClass,
Virtual,
DataBreakpoint,
String(String),
}Variants
Property
Indicates that the object is a property.
Method
Indicates that the object is a method.
Class
Indicates that the object is a class.
Data
Indicates that the object is data.
Event
Indicates that the object is an event.
BaseClass
Indicates that the object is a base class.
InnerClass
Indicates that the object is an inner class.
Interface
Indicates that the object is an interface.
MostDerivedClass
Indicates that the object is the most derived class.
Virtual
Indicates that the object is virtual, that means it is a synthetic object introduced by the adapter for rendering purposes, e.g. an index range for large arrays.
DataBreakpoint
Deprecated: Indicates that a data breakpoint is
registered for the object. The hasDataBreakpoint attribute should
generally be used instead.
String(String)