pub struct Breakpoint {
pub id: Option<i64>,
pub verified: bool,
pub message: Option<String>,
pub source: Option<Source>,
pub line: Option<i64>,
pub column: Option<i64>,
pub end_line: Option<i64>,
pub end_column: Option<i64>,
pub instruction_reference: Option<String>,
pub offset: Option<i64>,
}Expand description
Information about a breakpoint created in setBreakpoints, setFunctionBreakpoints, setInstructionBreakpoints, or setDataBreakpoints requests.
Fields
id: Option<i64>The identifier for the breakpoint. It is needed if breakpoint events are used to update or remove breakpoints.
verified: boolIf true, the breakpoint could be set (but not necessarily at the desired location).
message: Option<String>A message about the state of the breakpoint. This is shown to the user and can be used to explain why a breakpoint could not be verified.
source: Option<Source>The source where the breakpoint is located.
line: Option<i64>The start line of the actual range covered by the breakpoint.
column: Option<i64>Start position of the source range covered by the breakpoint. It is
measured in UTF-16 code units and the client capability columnsStartAt1
determines whether it is 0- or 1-based.
end_line: Option<i64>The end line of the actual range covered by the breakpoint.
end_column: Option<i64>End position of the source range covered by the breakpoint. It is measured
in UTF-16 code units and the client capability columnsStartAt1 determines
whether it is 0- or 1-based.
If no end line is given, then the end column is assumed to be in the start
line.
instruction_reference: Option<String>A memory reference to where the breakpoint is set.
offset: Option<i64>The offset from the instruction reference. This can be negative.