pub struct InstructionBreakpoint {
pub instruction_reference: String,
pub offset: Option<i64>,
pub condition: Option<String>,
pub hit_condition: Option<String>,
}Expand description
Properties of a breakpoint passed to the setInstructionBreakpoints request
Specfication: InstructionBreakpoint
Fields
instruction_reference: StringThe instruction reference of the breakpoint.
This should be a memory or instruction pointer reference from an
EvaluateResponse, Variable, StackFrame, GotoTarget, or
Breakpoint.
offset: Option<i64>The offset from the instruction reference. This can be negative.
condition: Option<String>An expression for conditional breakpoints.
It is only honored by a debug adapter if the corresponding capability
supportsConditionalBreakpoints is true.
hit_condition: Option<String>An expression that controls how many hits of the breakpoint are ignored.
The debug adapter is expected to interpret the expression as needed.
The attribute is only honored by a debug adapter if the corresponding
capability supportsHitConditionalBreakpoints is true.