pub struct Module {
pub id: ModuleId,
pub name: String,
pub path: Option<String>,
pub is_optimized: Option<bool>,
pub is_user_code: Option<bool>,
pub version: Option<String>,
pub symbol_status: Option<String>,
pub symbol_file_path: Option<String>,
pub date_time_stamp: Option<String>,
pub address_range: Option<String>,
}Fields
id: ModuleIdUnique identifier for the module.
name: StringA name of the module.
path: Option<String>Logical full path to the module. The exact definition is implementation defined, but usually this would be a full path to the on-disk file for the module.
is_optimized: Option<bool>True if the module is optimized.
is_user_code: Option<bool>True if the module is considered ‘user code’ by a debugger that supports ‘Just My Code’.
version: Option<String>Version of Module.
symbol_status: Option<String>User-understandable description of if symbols were found for the module (ex: ‘Symbols Loaded’, ‘Symbols not found’, etc.)
symbol_file_path: Option<String>Logical full path to the symbol file. The exact definition is implementation defined.
date_time_stamp: Option<String>Module created or modified, encoded as a RFC 3339 timestamp.
address_range: Option<String>Address range covered by this module.