pub struct Scope {
pub name: String,
pub presentation_hint: Option<ScopePresentationhint>,
pub variables_reference: i64,
pub named_variables: Option<i64>,
pub indexed_variables: Option<i64>,
pub expensive: bool,
pub source: Option<Source>,
pub line: Option<i64>,
pub column: Option<i64>,
pub end_line: Option<i64>,
pub end_column: Option<i64>,
}Expand description
A Scope is a named container for variables. Optionally a scope can map to a source or a range within a source.
Specification: Scope
Fields
name: StringName of the scope such as ‘Arguments’, ‘Locals’, or ‘Registers’. This String is shown in the UI as is and can be translated.
presentation_hint: Option<ScopePresentationhint>A hint for how to present this scope in the UI. If this attribute is
missing, the scope is shown with a generic UI.
Values:
‘arguments’: Scope contains method arguments.
‘locals’: Scope contains local variables.
‘registers’: Scope contains registers. Only a single registers scope
should be returned from a scopes request.
etc.
variables_reference: i64The variables of this scope can be retrieved by passing the value of
variablesReference to the variables request as long as execution
remains suspended. See Lifetime of Object References
in the Overview section of the specification for details.
named_variables: Option<i64>The i64 of named variables in this scope. The client can use this information to present the variables in a paged UI and fetch them in chunks.
indexed_variables: Option<i64>The i64 of indexed variables in this scope. The client can use this information to present the variables in a paged UI and fetch them in chunks.
expensive: boolIf true, the i64 of variables in this scope is large or expensive to retrieve.
source: Option<Source>The source for this scope.
line: Option<i64>The start line of the range covered by this scope.
column: Option<i64>Start position of the range covered by the scope. It is measured in UTF-16
code units and the client capability columnsStartAt1 determines whether
it is 0- or 1-based.
end_line: Option<i64>The end line of the range covered by this scope.
end_column: Option<i64>End position of the range covered by the scope. It is measured in UTF-16
code units and the client capability columnsStartAt1 determines whether
it is 0- or 1-based.