pub struct SourceBreakpoint {
pub line: i64,
pub column: Option<i64>,
pub condition: Option<String>,
pub hit_condition: Option<String>,
pub log_message: Option<String>,
}Fields
line: i64The source line of the breakpoint or logpoint.
column: Option<i64>Start position within source line of the breakpoint or logpoint. It is
measured in UTF-16 code units and the client capability columnsStartAt1
determines whether it is 0- or 1-based.
condition: Option<String>The expression for conditional breakpoints.
It is only honored by a debug adapter if the corresponding capability
supportsConditionalBreakpoints is true.
hit_condition: Option<String>The expression that controls how many hits of the breakpoint are ignored.
The debug adapter is expected to interpret the expression as needed.
The attribute is only honored by a debug adapter if the corresponding
capability supportsHitConditionalBreakpoints is true.
log_message: Option<String>If this attribute exists and is non-empty, the debug adapter must not
‘break’ (stop)
but log the message instead. Expressions within {} are interpolated.
The attribute is only honored by a debug adapter if the corresponding
capability supportsLogPoints is true.