pub struct StackFrame {
pub id: i64,
pub name: String,
pub source: Option<Source>,
pub line: i64,
pub column: i64,
pub end_line: Option<i64>,
pub end_column: Option<i64>,
pub can_restart: Option<bool>,
pub instruction_pointer_reference: Option<String>,
pub module_id: Option<StackFrameModuleid>,
pub presentation_hint: Option<StackFramePresentationhint>,
}Expand description
A Stackframe contains the source location.
Specification: StackFrame
Fields
id: i64An identifier for the stack frame. It must be unique across all threads.
This id can be used to retrieve the scopes of the frame with the scopes
request or to restart the execution of a stackframe.
name: StringThe name of the stack frame, typically a method name.
source: Option<Source>The source of the frame.
line: i64The line within the source of the frame. If the source attribute is missing
or doesn’t exist, line is 0 and should be ignored by the client.
column: i64Start position of the range covered by the stack frame. It is measured in
UTF-16 code units and the client capability columnsStartAt1 determines
whether it is 0- or 1-based. If attribute source is missing or doesn’t
exist, column is 0 and should be ignored by the client.
end_line: Option<i64>The end line of the range covered by the stack frame.
end_column: Option<i64>End position of the range covered by the stack frame. It is measured in
UTF-16 code units and the client capability columnsStartAt1 determines
whether it is 0- or 1-based.
can_restart: Option<bool>Indicates whether this frame can be restarted with the restart request.
Clients should only use this if the debug adapter supports the restart
request and the corresponding capability supportsRestartRequest is true.
instruction_pointer_reference: Option<String>A memory reference for the current instruction pointer in this frame.
module_id: Option<StackFrameModuleid>The module associated with this frame, if any.
presentation_hint: Option<StackFramePresentationhint>A hint for how to present this frame in the UI.
A value of label can be used to indicate that the frame is an artificial
frame that is used as a visual label or separator. A value of subtle can
be used to change the appearance of a frame in a ‘subtle’ way.
Values: ‘normal’, ‘label’, ‘subtle’