pub struct ProcessEventBody {
pub name: String,
pub system_process_id: Option<i64>,
pub is_local_process: Option<bool>,
pub start_method: Option<ProcessEventStartMethod>,
pub pointer_size: Option<i64>,
}Expand description
Arguments for an Process event.
Fields
name: StringThe logical name of the process. This is usually the full path to process’s executable file. Example: /home/example/myproj/program.js.
system_process_id: Option<i64>The system process id of the debugged process. This property is missing for non-system processes.
is_local_process: Option<bool>If true, the process is running on the same computer as the debug adapter.
start_method: Option<ProcessEventStartMethod>Describes how the debug engine started debugging this process. Values: ‘launch’: Process was launched under the debugger. ‘attach’: Debugger attached to an existing process. ‘attachForSuspendedLaunch’: A project launcher component has launched a new process in a suspended state and then asked the debugger to attach.
pointer_size: Option<i64>The size of a pointer or address for this process, in bits. This value may be used by clients when formatting addresses for display.