pub enum Command {
Show 42 variants
Attach(AttachRequestArguments),
BreakpointLocations(BreakpointLocationsArguments),
Completions(CompletionsArguments),
ConfigurationDone,
Continue(ContinueArguments),
DataBreakpointInfo(DataBreakpointInfoArguments),
Disassemble(DisassembleArguments),
Disconnect(DisconnectArguments),
Evaluate(EvaluateArguments),
ExceptionInfo(ExceptionInfoArguments),
Goto(GotoArguments),
GotoTargets(GotoTargetsArguments),
Initialize(InitializeArguments),
Launch(LaunchRequestArguments),
LoadedSources,
Modules(ModulesArguments),
Next(NextArguments),
Pause(PauseArguments),
ReadMemory(ReadMemoryArguments),
Restart(RestartArguments),
RestartFrame(RestartFrameArguments),
ReverseContinue(ReverseContinueArguments),
Scopes(ScopesArguments),
SetBreakpoints(SetBreakpointsArguments),
SetDataBreakpoints(SetDataBreakpointsArguments),
SetExceptionBreakpoints(SetExceptionBreakpointsArguments),
SetExpression(SetExpressionArguments),
SetFunctionBreakpoints(SetFunctionBreakpointsArguments),
SetInstructionBreakpoints(SetInstructionBreakpointsArguments),
SetVariable(SetVariableArguments),
Source(SourceArguments),
StackTrace(StackTraceArguments),
StepBack(StepBackArguments),
StepIn(StepInArguments),
StepInTargets(StepInTargetsArguments),
StepOut(StepOutArguments),
Terminate(TerminateArguments),
TerminateThreads(TerminateThreadsArguments),
Threads,
Variables(VariablesArguments),
WriteMemory(WriteMemoryArguments),
Cancel(CancelArguments),
}Variants
Attach(AttachRequestArguments)
The attach request is sent from the client to the debug adapter to attach to a debuggee that is already running. kSince attaching is debugger/runtime specific, the arguments for this request are not part of this specification.
Specification: Attach request
BreakpointLocations(BreakpointLocationsArguments)
The breakpointLocations request returns all possible locations for source breakpoints in a
given range.
Clients should only call this request if the corresponding capability
supportsBreakpointLocationsRequest is true.
Specification: BreakpointLocations request
Completions(CompletionsArguments)
Returns a list of possible completions for a given caret position and text.
Clients should only call this request if the corresponding capability
supportsCompletionsRequest is true.
Specification: [Completions request]: https://microsoft.github.io/debug-adapter-protocol/specification#Requests_Completions
ConfigurationDone
This request indicates that the client has finished initialization of the debug adapter. So it is the last request in the sequence of configuration requests (which was started by the initialized event). Clients should only call this request if the corresponding capability supportsConfigurationDoneRequest is true.
Specification: ConfigurationDone
Continue(ContinueArguments)
The request resumes execution of all threads. If the debug adapter supports single thread
execution (see capability supportsSingleThreadExecutionRequests), setting the singleThread
argument to true resumes only the specified thread. If not all threads were resumed, the
allThreadsContinued attribute of the response should be set to false.
Specification: Continue request
DataBreakpointInfo(DataBreakpointInfoArguments)
Obtains information on a possible data breakpoint that could be set on an expression or variable. Clients should only call this request if the corresponding capability supportsDataBreakpoints is true.
Specification: DataBreakpointInfo request
Disassemble(DisassembleArguments)
Disassembles code stored at the provided location.
Clients should only call this request if the corresponding capability
supportsDisassembleRequest is true.
Specification: Disassemble request
Disconnect(DisconnectArguments)
The disconnect request asks the debug adapter to disconnect from the debuggee (thus ending
the debug session) and then to shut down itself (the debug adapter).
In addition, the debug adapter must terminate the debuggee if it was started with the launch
request. If an attach request was used to connect to the debuggee, then the debug adapter
must not terminate the debuggee.
This implicit behavior of when to terminate the debuggee can be overridden with the
terminateDebuggee argument (which is only supported by a debug adapter if the corresponding
capability supportTerminateDebuggee is true).
Specification: Disconnect request
Evaluate(EvaluateArguments)
Evaluates the given expression in the context of the topmost stack frame. The expression has access to any variables and arguments that are in scope.
Specification: Evaluate arguments
ExceptionInfo(ExceptionInfoArguments)
Retrieves the details of the exception that caused this event to be raised.
Clients should only call this request if the corresponding capability
supportsExceptionInfoRequest is true.
Specification: ExceptionInfo request
Goto(GotoArguments)
The request sets the location where the debuggee will continue to run.
This makes it possible to skip the execution of code or to execute code again.
The code between the current location and the goto target is not executed but skipped.
The debug adapter first sends the response and then a stopped event with reason goto.
Clients should only call this request if the corresponding capability
supportsGotoTargetsRequest is true (because only then goto targets exist that can be passed
as arguments).
Specification: Goto request
GotoTargets(GotoTargetsArguments)
This request retrieves the possible goto targets for the specified source location.
These targets can be used in the goto request.
Clients should only call this request if the corresponding capability
supportsGotoTargetsRequest is true.
Specification: GotoTargets request
Initialize(InitializeArguments)
The initialize request is sent as the first request from the client to the debug adapter in order to configure it with client capabilities and to retrieve capabilities from the debug adapter.
Until the debug adapter has responded with an initialize response, the client must not send any additional requests or events to the debug adapter.
In addition the debug adapter is not allowed to send any requests or events to the client until it has responded with an initialize response.
The initialize request may only be sent once.
Specification: InitializeRequest
Launch(LaunchRequestArguments)
This launch request is sent from the client to the debug adapter to start the debuggee with or without debugging (if noDebug is true). Since launching is debugger/runtime specific, the arguments for this request are not part of this specification.
Specification: Launch request
LoadedSources
Retrieves the set of all sources currently loaded by the debugged process. Clients should only call this request if the corresponding capability supportsLoadedSourcesRequest is true.
Specification: LoadedSources request
Modules(ModulesArguments)
Modules can be retrieved from the debug adapter with this request which can either return
all modules or a range of modules to support paging.
Clients should only call this request if the corresponding capability
supportsModulesRequest is true.
Specification: Modules request
Next(NextArguments)
The request executes one step (in the given granularity) for the specified thread and allows
all other threads to run freely by resuming them.
If the debug adapter supports single thread execution (see capability
supportsSingleThreadExecutionRequests), setting the singleThread argument to true
prevents other suspended threads from resuming.
The debug adapter first sends the response and then a stopped event (with reason step) after
the step has completed.
Specification: Next request
Pause(PauseArguments)
The request suspends the debuggee.
The debug adapter first sends the response and then a stopped event (with reason pause)
after the thread has been paused successfully.
Specification: Pause request
ReadMemory(ReadMemoryArguments)
Reads bytes from memory at the provided location.
Clients should only call this request if the corresponding capability
supportsReadMemoryRequest is true.
Specification: ReadMemory request
Restart(RestartArguments)
Restarts a debug session. Clients should only call this request if the corresponding capability supportsRestartRequest is true. If the capability is missing or has the value false, a typical client emulates restart by terminating the debug adapter first and then launching it anew.
Specification: Restart request
RestartFrame(RestartFrameArguments)
The request restarts execution of the specified stackframe.
The debug adapter first sends the response and then a stopped event (with reason restart)
after the restart has completed.
Clients should only call this request if the corresponding capability supportsRestartFrame
is true.
Specification: RestartFrame request
ReverseContinue(ReverseContinueArguments)
The request resumes backward execution of all threads. If the debug adapter supports single
thread execution (see capability supportsSingleThreadExecutionRequests), setting the
singleThread argument to true resumes only the specified thread. If not all threads were
resumed, the allThreadsContinued attribute of the response should be set to false.
Clients should only call this request if the corresponding capability supportsStepBack is true.
Specification: ReverseContinue request
Scopes(ScopesArguments)
The request returns the variable scopes for a given stackframe ID.
Specification: Scopes request
SetBreakpoints(SetBreakpointsArguments)
Sets multiple breakpoints for a single source and clears all previous breakpoints in that source.
To clear all breakpoint for a source, specify an empty array.
When a breakpoint is hit, a stopped event (with reason breakpoint) is generated.
Specification: SetBreakpointsRequest
SetDataBreakpoints(SetDataBreakpointsArguments)
Replaces all existing data breakpoints with new data breakpoints.
To clear all data breakpoints, specify an empty array.
When a data breakpoint is hit, a stopped event (with reason data breakpoint) is generated.
Clients should only call this request if the corresponding capability
supportsDataBreakpoints is true.
Specification: SetDataBreakpoints request
SetExceptionBreakpoints(SetExceptionBreakpointsArguments)
The request configures the debugger’s response to thrown exceptions. If an exception is configured to break, a stopped event is fired (with reason exception). Clients should only call this request if the corresponding capability exceptionBreakpointFilters returns one or more filters.
Specification: SetExceptionBreakpoints
SetExpression(SetExpressionArguments)
Evaluates the given value expression and assigns it to the expression which must be a
modifiable l-value.
The expressions have access to any variables and arguments that are in scope of the specified
frame.
Clients should only call this request if the corresponding capability supportsSetExpression
is true.
If a debug adapter implements both setExpression and setVariable, a client uses
setExpression if the variable has an evaluateName property.
Specification: SetExpression request
SetFunctionBreakpoints(SetFunctionBreakpointsArguments)
Replaces all existing function breakpoints with new function breakpoints. To clear all function breakpoints, specify an empty array. When a function breakpoint is hit, a stopped event (with reason function breakpoint) is generated. Clients should only call this request if the corresponding capability supportsFunctionBreakpoints is true.
Specification: SetFunctionBreakpointsArguments
SetInstructionBreakpoints(SetInstructionBreakpointsArguments)
Replaces all existing instruction breakpoints. Typically, instruction breakpoints would be set from a disassembly window.
To clear all instruction breakpoints, specify an empty array.
When an instruction breakpoint is hit, a stopped event (with reason
instruction breakpoint) is generated.
Clients should only call this request if the corresponding capability
supportsInstructionBreakpoints is true.
Specification: SetInstructionBreakpoints request
SetVariable(SetVariableArguments)
Set the variable with the given name in the variable container to a new value. Clients should
only call this request if the corresponding capability supportsSetVariable is true.
If a debug adapter implements both setVariable and setExpression, a client will only use
setExpression if the variable has an evaluateName property.
Specification: SetVariable request
Source(SourceArguments)
The request retrieves the source code for a given source reference.
Specification: Sources request
StackTrace(StackTraceArguments)
The request returns a stacktrace from the current execution state of a given thread.
A client can request all stack frames by omitting the startFrame and levels arguments. For
performance-conscious clients and if the corresponding capability
supportsDelayedStackTraceLoading is true, stack frames can be retrieved in a piecemeal way
with the startFrame and levels arguments. The response of the stackTrace request may
contain a totalFrames property that hints at the total number of frames in the stack. If a
client needs this total number upfront, it can issue a request for a single (first) frame
and depending on the value of totalFrames decide how to proceed. In any case a client should
be prepared to receive fewer frames than requested, which is an indication that the end of
the stack has been reached.
Specification: StackTrace request
StepBack(StepBackArguments)
The request executes one backward step (in the given granularity) for the specified thread
and allows all other threads to run backward freely by resuming them.
If the debug adapter supports single thread execution (see capability
supportsSingleThreadExecutionRequests), setting the singleThread argument to true prevents
other suspended threads from resuming.
The debug adapter first sends the response and then a stopped event (with reason step) after
the step has completed.
Clients should only call this request if the corresponding capability supportsStepBack is
true.
Specification: StepBack request
StepIn(StepInArguments)
The request resumes the given thread to step into a function/method and allows all other
threads to run freely by resuming them.
If the debug adapter supports single thread execution (see capability
supportsSingleThreadExecutionRequests), setting the singleThread argument to true
prevents other suspended threads from resuming.
Specification: StepIn request
StepInTargets(StepInTargetsArguments)
This request retrieves the possible step-in targets for the specified stack frame.
These targets can be used in the stepIn request.
Clients should only call this request if the corresponding capability
supportsStepInTargetsRequest is true.
Specification: StepInTargets request
StepOut(StepOutArguments)
The request resumes the given thread to step out (return) from a function/method and allows
all other threads to run freely by resuming them.
If the debug adapter supports single thread execution (see capability
supportsSingleThreadExecutionRequests), setting the singleThread argument to true prevents
other suspended threads from resuming.
The debug adapter first sends the response and then a stopped event (with reason step) after
the step has completed.
Specification: StepOut request
Terminate(TerminateArguments)
The terminate request is sent from the client to the debug adapter in order to shut down the
debuggee gracefully. Clients should only call this request if the capability
supportsTerminateRequest is true.
Specification: Terminate request
TerminateThreads(TerminateThreadsArguments)
The request terminates the threads with the given ids.
Clients should only call this request if the corresponding capability
supportsTerminateThreadsRequest is true.
Specification: TerminateThreads request
Threads
The request retrieves a list of all threads.
Specification: Threads request
Variables(VariablesArguments)
Retrieves all child variables for the given variable reference. A filter can be used to limit the fetched children to either named or indexed children.
Specification: Variables request
WriteMemory(WriteMemoryArguments)
Writes bytes to memory at the provided location.
Clients should only call this request if the corresponding capability
supportsWriteMemoryRequest is true.
Specification: WriteMemory request
Cancel(CancelArguments)
The cancel request is used by the client in two situations:
to indicate that it is no longer interested in the result produced by a specific request issued earlier to cancel a progress sequence. Clients should only call this request if the corresponding capability supportsCancelRequest is true.
Specification: CancelRequest