pub enum ResponseBody {
Show 40 variants
Attach,
BreakpointLocations(BreakpointLocationsResponse),
Completions(CompletionsResponse),
ConfigurationDone,
Continue(ContinueResponse),
DataBreakpointInfo(DataBreakpointInfoResponse),
Disassemble(DisassembleResponse),
Disconnect,
Evaluate(EvaluateResponse),
ExceptionInfo(ExceptionInfoResponse),
Goto,
GotoTargets(GotoTargetsResponse),
Initialize(Capabilities),
Launch,
LoadedSources(LoadedSourcesResponse),
Modules(ModulesResponse),
Next,
Pause,
ReadMemory(ReadMemoryResponse),
Restart,
RestartFrame,
ReverseContinue,
Scopes(ScopesResponse),
SetBreakpoints(SetBreakpointsResponse),
SetDataBreakpoints(SetDataBreakpointsResponse),
SetExceptionBreakpoints(SetExceptionBreakpointsResponse),
SetExpression(SetExpressionResponse),
SetFunctionBreakpoints(SetFunctionBreakpointsResponse),
SetInstructionBreakpoints(SetInstructionBreakpointsResponse),
SetVariable(SetVariableResponse),
Source(SourceResponse),
StackTrace(StackTraceResponse),
StepBack,
StepIn,
StepOut,
Terminate,
TerminateThreads,
Threads(ThreadsResponse),
Variables(VariablesResponse),
WriteMemory(WriteMemoryResponse),
}Variants
Attach
Response to attach request. This is just an acknowledgement, so no body field is required.
Specification: Attach request
BreakpointLocations(BreakpointLocationsResponse)
Response to breakpointLocations request. Contains possible locations for source breakpoints.
Specification: BreakpointLocations request
Completions(CompletionsResponse)
Response to a completions request
Specification: Completions request
ConfigurationDone
Response to configurationDone request. This is just an acknowledgement, so no body field is
required.
Specification: ConfigurationDone request
Continue(ContinueResponse)
Response to continue request.
Specification: Continue request
DataBreakpointInfo(DataBreakpointInfoResponse)
Response to dataBreakpointInfo request.
Specification: DataBreakpointInfo request
Disassemble(DisassembleResponse)
Response to disassemble request.
NOTE: we are straying away from the spec here, as the spec says that the response body is optional, but we are always returning a body because I could not find a way to express skipping the optional body with serde (and serializing null will make the schema validation complain).
Specification: Disassembly request
Disconnect
Response to disconnect request. This is just an acknowledgement, so no body field is required.
Specification: Disconnect request
Evaluate(EvaluateResponse)
Response to evaluate request.
Specification: Evaluate request
ExceptionInfo(ExceptionInfoResponse)
Response to exceptionInfo request.
Specification: ExceptionInfo
Goto
Response to goto request. This is just an acknowledgement, so no body field is required.
Specification: Goto request
GotoTargets(GotoTargetsResponse)
Response to gotoTargets request.
Specification: GotoTargets request
Initialize(Capabilities)
Response to initialize request.
NOTE: we are straying away from the spec here, as the spec says that the response body is optional, but we are always returning a body because I could not find a way to express skipping the optional body with serde (and serializing null will make the schema validation complain).
Specification: Initialize request
Launch
Response to launch request. This is just an acknowledgement, so no body field is required.
Specification: Launch request
LoadedSources(LoadedSourcesResponse)
Response to loadedSources request.
Specification: LoadedSources request
Modules(ModulesResponse)
Response to modules request.
Specification: Modules request
Next
Response to next request. This is just an acknowledgement, so no body field is required.
Specification: Next request
Pause
Response to pause request. This is just an acknowledgement, so no body field is required.
Specification: Pause request
ReadMemory(ReadMemoryResponse)
Response to readMemory request.
NOTE: we are straying away from the spec here, as the spec says that the response body is optional, but we are always returning a body because I could not find a way to express skipping the optional body with serde (and serializing null will make the schema validation complain).
Specification: ReadMemory request
Restart
Response to restart request. This is just an acknowledgement, so no body field is required.
Specification: Restart request
RestartFrame
Response to restartFrame request. This is just an acknowledgement, so no body field is
required.
Specification: RestartFrame request
ReverseContinue
Response to reverseContinue request. This is just an acknowledgement, so no body field is
required.
Specification: ReverseContinue request
Scopes(ScopesResponse)
Response to scopes request.
Specification: Scopes request
SetBreakpoints(SetBreakpointsResponse)
Response to setBreakpoints request. Returned is information about each breakpoint created by this request. This includes the actual code location and whether the breakpoint could be verified. The breakpoints returned are in the same order as the elements of the breakpoints (or the deprecated lines) array in the arguments.
Specification: SetBreakpointsRequest
SetDataBreakpoints(SetDataBreakpointsResponse)
Replaces all existing data breakpoints with new data breakpoints.
To clear all data breakpoints, specify an empty array.
When a data breakpoint is hit, a stopped event (with reason date breakpoint) is generated.
Clients should only call this request if the corresponding capability
supportsDataBreakpoints is true.
Specification: SetDataBreakpoints request
SetExceptionBreakpoints(SetExceptionBreakpointsResponse)
Response to setExceptionBreakpoint request.
The response contains an array of Breakpoint objects with information about each exception
breakpoint or filter. The Breakpoint objects are in the same order as the elements of the
filters, filterOptions, exceptionOptions arrays given as arguments. If both filters
and filterOptions are given, the returned array must start with filters information first,
followed by filterOptions information.
The verified property of a Breakpoint object signals whether the exception breakpoint or
filter could be successfully created and whether the condition or hit count expressions are
valid. In case of an error the message property explains the problem. The id property can be
used to introduce a unique ID for the exception breakpoint or filter so that it can be
updated subsequently by sending breakpoint events.
For backward compatibility both the breakpoints array and the enclosing body are optional.
If these elements are missing a client is not able to show problems for individual exception
breakpoints or filters.
NOTE: we are straying away from the spec here, as the spec says that the response body is optional, but we are always returning a body because I could not find a way to express skipping the optional body with serde (and serializing null will make the schema validation complain).
SetExpression(SetExpressionResponse)
Response to setExpression request.
Specification: SetExpression request
SetFunctionBreakpoints(SetFunctionBreakpointsResponse)
Response to setFunctionBreakpoints request. Returned is information about each breakpoint created by this request.
Specification: SetFunctionBreakpointsArguments
SetInstructionBreakpoints(SetInstructionBreakpointsResponse)
Response to setInstructionBreakpoints request
Specification: SetInstructionBreakpoints request
SetVariable(SetVariableResponse)
Response to setVariable request.
Specification: SetVariable request
Source(SourceResponse)
Response to source request.
Specification: Sources request
StackTrace(StackTraceResponse)
Response to stackTrace request.
Specification: StackTrace request
StepBack
Response to stepBack request. This is just an acknowledgement, so no body field is required.
Specification: StepBack request
StepIn
Response to stepIn request. This is just an acknowledgement, so no body field is required.
Specification: StepIn request
StepOut
Response to stepOut request. This is just an acknowledgement, so no body field is required.
Specification: StepOut request
Terminate
Response to terminate request. This is just an acknowledgement, so no body field is required.
Specification: Terminate request
TerminateThreads
Response to terminateThreads request. This is just an acknowledgement, so no body field is
required.
Specification: TerminateThreads request
Threads(ThreadsResponse)
Response to threads request.
Specification: Threads request
Variables(VariablesResponse)
Response to variables request.
Specification: Variables request
WriteMemory(WriteMemoryResponse)
Response to writeMemory request.
NOTE: we are straying away from the spec here, as the spec says that the response body is optional, but we are always returning a body because I could not find a way to express skipping the optional body with serde (and serializing null will make the schema validation complain).
Specification: WriteMemory request