pub struct ContinueResponse {
pub all_threads_continued: Option<bool>,
}Fields
all_threads_continued: Option<bool>The value true (or a missing property) signals to the client that all threads have been resumed. The value false indicates that not all threads were resumed.