pub struct WriteMemoryResponse {
pub offset: Option<i64>,
pub bytes_written: Option<i64>,
}Fields
offset: Option<i64>Property that should be returned when allowPartial is true to indicate
the offset of the first byte of data successfully written. Can be
negative.
bytes_written: Option<i64>Property that should be returned when allowPartial is true to indicate
the i64 of bytes starting from address that were successfully written.