pub enum ReverseCommand {
RunInTerminal(RunInTerminalRequestArguments),
StartDebugging(StartDebuggingRequestArguments),
}Variants
RunInTerminal(RunInTerminalRequestArguments)
This request is sent from the debug adapter to the client to run a command in a terminal.
This is typically used to launch the debuggee in a terminal provided by the client.
This request should only be called if the corresponding client capability
supportsRunInTerminalRequest is true.
Client implementations of runInTerminal are free to run the command however they choose
including issuing the command to a command line interpreter (aka ‘shell’). Argument strings
passed to the runInTerminal request must arrive verbatim in the command to be run.
As a consequence, clients which use a shell are responsible for escaping any special shell
characters in the argument strings to prevent them from being interpreted (and modified) by
the shell.
Some users may wish to take advantage of shell processing in the argument strings. For
clients which implement runInTerminal using an intermediary shell, the
argsCanBeInterpretedByShell property can be set to true. In this case the client is
requested not to escape any special shell characters in the argument strings.
Specification: RunInTerminal
StartDebugging(StartDebuggingRequestArguments)
This request is sent from the debug adapter to the client to start a new debug session of the same type as the caller.
This request should only be sent if the corresponding client capability
supportsStartDebuggingRequest is true.
Specification: StartDebugging