pub struct StartDebuggingRequestArguments {
pub configuration: HashMap<String, Value>,
pub request: StartDebuggingRequestKind,
}Fields
configuration: HashMap<String, Value>Arguments passed to the new debug session. The arguments must only contain
properties understood by the launch or attach requests of the debug
adapter and they must not contain any client-specific properties (e.g.
type) or client-specific features (e.g. substitutable ‘variables’).
request: StartDebuggingRequestKindIndicates whether the new debug session should be started with a launch
or attach request.
Values: ‘launch’, ‘attach’