pub struct ServerOutput<W: Write> { /* private fields */ }Expand description
Handles emission of messages through the connection.
ServerOutput is responsible for sending messages to the connection.
It’s only accessible through a mutex that can be shared with other
threads. This makes it possible to send e.g. events while the server is
blocked polling requests.
Implementations
Sourceimpl<W: Write> ServerOutput<W>
impl<W: Write> ServerOutput<W>
pub fn send(&mut self, body: Sendable) -> Result<(), ServerError>
pub fn respond(&mut self, response: Response) -> Result<(), ServerError>
pub fn send_event(&mut self, event: Event) -> Result<(), ServerError>
pub fn send_reverse_request( &mut self, request: ReverseRequest, ) -> Result<(), ServerError>