Structs
- Breakpoint
- Information about a breakpoint created in setBreakpoints, setFunctionBreakpoints, setInstructionBreakpoints, or setDataBreakpoints requests.
- Breakpoint
Location - Properties of a breakpoint location returned from the breakpointLocations request. Specfication: BreakpointLocation
- Capabilities
- Checksum
- Column
Descriptor - Completion
Item CompletionItemsare the suggestions returned from thecompletionsrequest.- Custom
Value - Data
Breakpoint - Disassembled
Instruction - Represents a single disassembled instruction.
- Exception
Breakpoints Filter - Exception
Details - Detailed information about an exception that has occurred.
- Exception
Filter Options - An ExceptionFilterOptions is used to specify an exception filter together with a condition for the setExceptionBreakpoints request.
- Exception
Options - An ExceptionOptions assigns configuration options to a set of exceptions.
- Exception
Path Segment - An ExceptionPathSegment represents a segment in a path that is used to match leafs or nodes in a tree of exceptions. If a segment consists of more than one name, it matches the names provided if negate is false or missing, or it matches anything except the names provided if negate is true.
- Function
Breakpoint - Properties of a breakpoint passed to the setFunctionBreakpoints request.
- Goto
Target - A
GotoTargetdescribes a code location that can be used as a target in the goto request. The possible goto targets can be determined via the gotoTargets request. - Instruction
Breakpoint - Properties of a breakpoint passed to the setInstructionBreakpoints request
- Message
- A structured message object. Used to return errors from requests.
- Module
- Scope
- A Scope is a named container for variables. Optionally a scope can map to a source or a range within a source.
- Source
- A Source is a descriptor for source code.
- Source
Breakpoint - Stack
Frame - A Stackframe contains the source location.
- Stack
Frame Format - Thread
- A thread.
- Value
Format - Variable
- A Variable is a name/value pair.
- Variable
Presentation Hint
Enums
- Breakpoint
Event Reason - Checksum
Algorithm - Column
Descriptor Type - Completion
Item Type - Some predefined types for the CompletionItem. Please note that not all clients have specific icons for all of them
- Data
Breakpoint Access Type - Evaluate
Arguments Context - Exception
Break Mode - This enumeration defines all possible conditions when a thrown exception should result in a break.
- Invalidated
Areas - Loaded
Source Event Reason - Module
Event Reason - Module
Id - Output
Event Category - Output
Event Group - Presentation
Hint - Process
Event Start Method - RunIn
Terminal Request Arguments Kind - Scope
Presentationhint - A hint for how to present this scope in the UI. If this attribute is missing, the scope is shown with a generic UI.
- Stack
Frame Moduleid - Stack
Frame Presentationhint - Start
Debugging Request Kind - Stepping
Granularity - Stopped
Event Reason - Thread
Event Reason - Variable
Presentation Hint Attributes - Set of attributes represented as an array of Strings. Before introducing additional values, try to use the listed values.
- Variable
Presentation Hint Kind - Variable
Presentation Hint Visibility - Variables
Arguments Filter